==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/updatenotification/l10n/it.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Channel updated" : "Canale aggiornato",
    "Web updater is disabled" : "L'aggiornamento web è disattivato",
    "Configuration is read-only" : "La configurazione è di sola lettura",
    "App updated" : "App aggiornata",
    "See what's new" : "Guarda cosa c'è di nuovo",
    "{app} updated to version {version}" : "{app} aggiornata alla versione {version}",
    "Update notifications" : "Notifiche degli aggiornamenti",
    "The update server could not be reached since %d days to check for new updates." : "Il server degli aggiornamenti non è raggiungibile da %d giorni per controllare la presenza di nuovi aggiornamenti.",
    "Please check the Nextcloud and server log files for errors." : "Controlla i file di log di Nextcloud e del server alla ricerca di errori.",
    "Update to {serverAndVersion} is available." : "Aggiornamento a {serverAndVersion} disponibile.",
    "Update for {app} to version %s is available." : "È disponibile l'aggiornamento di {app} alla versione %s.",
    "Update notification" : "Notifica di aggiornamento",
    "Displays update notifications for Nextcloud, app updates, and provides the SSO for the updater." : "Visualizza le notifiche di aggiornamento per Nextcloud, gli aggiornamenti dell'app e fornisce l'SSO per l'aggiornamento.",
    "Give feedback" : "Dai un feedback",
    "Get started" : "Cominciamo",
    "No changelog available" : "Nessuna nota di rilascio disponibile",
    "What's new in {app} {version}" : "Novità in {app} {version}",
    "A new version is available: <strong>{newVersionString}</strong>" : "Una nuova versione è disponibile: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Nota che, dopo una nuova versione, l'aggiornamento viene mostrato solo dopo la prima versione minore o successivamente. Pubblichiamo nel tempo nuove versioni e, a volte, ne saltiamo una se troviamo dei problemi. Ulteriori informazioni sugli aggiornamenti e sui canali di rilascio su {link}",
    "Checked on {lastCheckedDate} - Open changelog" : "Controllato il {lastCheckedDate} - Apri note di rilascio",
    "Checking apps for compatible versions" : "Controllo di applicazioni con versioni compatibili",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Assicurati che il tuo config.php non abbia <samp>appstoreenabled</samp> impostata a false.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Impossibile connettersi al negozio delle applicazioni o il negozio delle applicazioni non ha restituito alcun aggiornamento. Cerca manualmente gli aggiornamenti o assicurati che il server abbia accesso a Internet e possa collegarsi al negozio delle applicazioni.",
    "<strong>All</strong> apps have a compatible version for this {productName} version available." : "<strong>Tutte</strong> le app hanno una versione compatibile con questa versione di {productName}.",
    "_<strong>%n</strong> app has no compatible version for this {productName} version available._::_<strong>%n</strong> apps have no compatible version for this {productName} version available._" : ["<strong>%n</strong> app non ha una versione compatibile per questa versione di {productName} ","<strong>%n</strong> app non hanno una versione compatibile per questa versione di {productName}.","<strong>%n</strong> app non hanno una versione compatibile per questa versione di {productName}."],
    "Enterprise" : "Enterprise",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately." : "Per uso aziendale. Fornisce sempre il livello di patch più recente, ma non esegue immediatamente l'aggiornamento alla versione principale successiva.",
    "That update happens once {vendor} has done additional hardening and testing for large-scale and mission-critical deployments." : "L'aggiornamento avverrà una volta che {vendor} avrà completato ulteriori rafforzamenti e test per implementazioni su larga scala e mission-critical.",
    "This channel is only available to customers and provides the {enterprise} package." : "Questo canale è disponibile solo per i clienti e fornisce il pacchetto {enterprise}.",
    "Stable" : "Stabile",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "La versione stabile più recente. È appropriata per l'utilizzo di tutti i giorni e sarà sempre aggiornata all'ultima versione principale.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Una versione pre-rilascio solo per provare le nuove funzionalità, non per ambienti di produzione.",
    "Update" : "Aggiorna",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "La versione che stai eseguendo non è più mantenuta. Assicurati di aggiornare a una versione supportata non appena possibile.",
    "Apps missing compatible version" : "Applicazioni senza versione compatibile",
    "View in store" : "Visualizza nel negozio",
    "Apps with compatible version" : "Applicazioni con versione compatibile",
    "Please note that the web updater is not recommended with more than 100 accounts! Please use the command line updater instead!" : "Tieni presente che il programma di aggiornamento web non è consigliato con più di 100 account! Si prega di utilizzare, invece, il programma di aggiornamento tramite riga di comando!",
    "Open updater" : "Apri strumento di aggiornamento",
    "Download now" : "Scarica ora",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "Programma di aggiornamento web disattivato. Usa quello da riga di comando o il meccanismo di aggiornamento appropriato per il tuo metodo di installazione (es. Docker pull).",
    "What's new?" : "Cosa c'è di nuovo?",
    "View changelog" : "Visualizza le novità",
    "The update check is not yet finished. Please refresh the page." : "Il controllo degli aggiornamenti non è ancora terminato. Aggiorna la pagina.",
    "Your version is up to date." : "La tua versione è aggiornata.",
    "A non-default update server is in use to be checked for updates:" : "Stai utilizzando un server non predefinito per controllare gli aggiornamenti:",
    "Update channel" : "Canale di aggiornamento",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Cambiare il canale di aggiornamento influisce anche la pagina di gestione delle applicazioni. Es. dopo il passaggio al canale beta, ti verranno offerti gli aggiornamenti delle applicazioni beta nella pagina di gestione delle applicazioni.",
    "Current update channel:" : "Canale di aggiornamento attuale:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Puoi aggiornare sempre a una nuova versione. Ma non puoi mai tornare a una versione precedente.",
    "Notify members of the following groups about available updates:" : "Notifica ai membri dei seguenti gruppi la disponibilità di aggiornamenti:",
    "No groups" : "Nessun gruppo",
    "Only notifications for app updates are available." : "Sono disponibili solo le notifiche per gli aggiornamenti delle applicazioni.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Il canale di aggiornamento selezionato rende obsolete le notifiche dedicate al server.",
    "The selected update channel does not support updates of the server." : "Il canale di aggiornamento selezionato non supporta gli aggiornamenti del server.",
    "Changelog for app {app}" : "Note di rilascio per l'app {app}",
    "What's new in {app} version {version}" : "Novità nella versione {version} di {app}",
    "{version} is available. Get more information on how to update." : "{version} è disponibile. Ottieni ulteriori informazioni su come eseguire l'aggiornamento.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Tutte</strong> le applicazioni hanno una versione compatibile disponibile per questa versione di Nextcloud.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> applicazione non ha una versione compatibile disponibile per questa versione di Nextcloud.","<strong>%n</strong> applicazioni non hanno una versione compatibile disponibile per questa versione di Nextcloud.","<strong>%n</strong> applicazioni non hanno una versione compatibile disponibile per questa versione di Nextcloud."],
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Per utilizzo aziendale. Fornisce sempre l'ultimo livello di patch, ma non sarà aggiornato immediatamente all'ultima versione principale. Tale aggiornamento sarà disponibile nel momento in cui Nextcloud GmbH avrà apportato miglioramenti della sicurezza, test su larga scala e installazioni in ambienti di importanza rilevante. Questo canale è disponibile solo per i clienti e fornisce il pacchetto Nextcloud Enterprise."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/updatenotification/l10n/it.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Channel updated" : "Canale aggiornato",
    "Web updater is disabled" : "L'aggiornamento web è disattivato",
    "Configuration is read-only" : "La configurazione è di sola lettura",
    "App updated" : "App aggiornata",
    "See what's new" : "Guarda cosa c'è di nuovo",
    "{app} updated to version {version}" : "{app} aggiornata alla versione {version}",
    "Update notifications" : "Notifiche degli aggiornamenti",
    "The update server could not be reached since %d days to check for new updates." : "Il server degli aggiornamenti non è raggiungibile da %d giorni per controllare la presenza di nuovi aggiornamenti.",
    "Please check the Nextcloud and server log files for errors." : "Controlla i file di log di Nextcloud e del server alla ricerca di errori.",
    "Update to {serverAndVersion} is available." : "Aggiornamento a {serverAndVersion} disponibile.",
    "Update for {app} to version %s is available." : "È disponibile l'aggiornamento di {app} alla versione %s.",
    "Update notification" : "Notifica di aggiornamento",
    "Displays update notifications for Nextcloud, app updates, and provides the SSO for the updater." : "Visualizza le notifiche di aggiornamento per Nextcloud, gli aggiornamenti dell'applicazione e fornisce l'SSO per l'aggiornamento.",
    "Give feedback" : "Dai un riscontro",
    "Get started" : "Cominciamo",
    "No changelog available" : "Nessuna nota di rilascio disponibile",
    "What's new in {app} {version}" : "Novità in {app} {version}",
    "A new version is available: <strong>{newVersionString}</strong>" : "Una nuova versione è disponibile: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Nota che, dopo una nuova versione, l'aggiornamento viene mostrato solo dopo la prima versione minore o successivamente. Pubblichiamo nel tempo nuove versioni e, a volte, ne saltiamo una se troviamo dei problemi. Ulteriori informazioni sugli aggiornamenti e sui canali di rilascio su {link}",
    "Checked on {lastCheckedDate} - Open changelog" : "Controllato il {lastCheckedDate} - Apri note di rilascio",
    "Checking apps for compatible versions" : "Controllo di applicazioni con versioni compatibili",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Assicurati che il tuo config.php non abbia <samp>appstoreenabled</samp> impostata a false.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Impossibile connettersi al negozio delle applicazioni o il negozio delle applicazioni non ha restituito alcun aggiornamento. Cerca manualmente gli aggiornamenti o assicurati che il server abbia accesso a Internet e possa collegarsi al negozio delle applicazioni.",
    "<strong>All</strong> apps have a compatible version for this {productName} version available." : "<strong>Tutte</strong> le app hanno una versione compatibile con questa versione di {productName}.",
    "_<strong>%n</strong> app has no compatible version for this {productName} version available._::_<strong>%n</strong> apps have no compatible version for this {productName} version available._" : ["<strong>%n</strong> app non ha una versione compatibile per questa versione di {productName} ","<strong>%n</strong> app non hanno una versione compatibile per questa versione di {productName}.","<strong>%n</strong> app non hanno una versione compatibile per questa versione di {productName}."],
    "Enterprise" : "Enterprise",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately." : "Per uso aziendale. Fornisce sempre il livello di patch più recente, ma non esegue immediatamente l'aggiornamento alla versione principale successiva.",
    "That update happens once {vendor} has done additional hardening and testing for large-scale and mission-critical deployments." : "L'aggiornamento avverrà una volta che {vendor} avrà completato ulteriori rafforzamenti e test per implementazioni su larga scala e mission-critical.",
    "This channel is only available to customers and provides the {enterprise} package." : "Questo canale è disponibile solo per i clienti e fornisce il pacchetto {enterprise}.",
    "Stable" : "Stabile",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "La versione stabile più recente. È appropriata per l'utilizzo di tutti i giorni e sarà sempre aggiornata all'ultima versione principale.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Una versione pre-rilascio solo per provare le nuove funzionalità, non per ambienti di produzione.",
    "Update" : "Aggiorna",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "La versione che stai eseguendo non è più mantenuta. Assicurati di aggiornare a una versione supportata non appena possibile.",
    "Apps missing compatible version" : "Applicazioni senza versione compatibile",
    "View in store" : "Visualizza nel negozio",
    "Apps with compatible version" : "Applicazioni con versione compatibile",
    "Please note that the web updater is not recommended with more than 100 accounts! Please use the command line updater instead!" : "Tieni presente che il programma di aggiornamento web non è consigliato con più di 100 account! Si prega di utilizzare, invece, il programma di aggiornamento tramite riga di comando!",
    "Open updater" : "Apri strumento di aggiornamento",
    "Download now" : "Scarica ora",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "Programma di aggiornamento web disattivato. Usa quello da riga di comando o il meccanismo di aggiornamento appropriato per il tuo metodo di installazione (es. Docker pull).",
    "What's new?" : "Cosa c'è di nuovo?",
    "View changelog" : "Visualizza le novità",
    "The update check is not yet finished. Please refresh the page." : "Il controllo degli aggiornamenti non è ancora terminato. Aggiorna la pagina.",
    "Your version is up to date." : "La tua versione è aggiornata.",
    "A non-default update server is in use to be checked for updates:" : "Stai utilizzando un server non predefinito per controllare gli aggiornamenti:",
    "Update channel" : "Canale di aggiornamento",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Cambiare il canale di aggiornamento influisce anche la pagina di gestione delle applicazioni. Es. dopo il passaggio al canale beta, ti verranno offerti gli aggiornamenti delle applicazioni beta nella pagina di gestione delle applicazioni.",
    "Current update channel:" : "Canale di aggiornamento attuale:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Puoi aggiornare sempre a una nuova versione. Ma non puoi mai tornare a una versione precedente.",
    "Notify members of the following groups about available updates:" : "Notifica ai membri dei seguenti gruppi la disponibilità di aggiornamenti:",
    "No groups" : "Nessun gruppo",
    "Only notifications for app updates are available." : "Sono disponibili solo le notifiche per gli aggiornamenti delle applicazioni.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Il canale di aggiornamento selezionato rende obsolete le notifiche dedicate al server.",
    "The selected update channel does not support updates of the server." : "Il canale di aggiornamento selezionato non supporta gli aggiornamenti del server.",
    "Changelog for app {app}" : "Note di rilascio per l'app {app}",
    "What's new in {app} version {version}" : "Novità nella versione {version} di {app}",
    "{version} is available. Get more information on how to update." : "{version} è disponibile. Ottieni ulteriori informazioni su come eseguire l'aggiornamento.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Tutte</strong> le applicazioni hanno una versione compatibile disponibile per questa versione di Nextcloud.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> applicazione non ha una versione compatibile disponibile per questa versione di Nextcloud.","<strong>%n</strong> applicazioni non hanno una versione compatibile disponibile per questa versione di Nextcloud.","<strong>%n</strong> applicazioni non hanno una versione compatibile disponibile per questa versione di Nextcloud."],
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Per utilizzo aziendale. Fornisce sempre l'ultimo livello di patch, ma non sarà aggiornato immediatamente all'ultima versione principale. Tale aggiornamento sarà disponibile nel momento in cui Nextcloud GmbH avrà apportato miglioramenti della sicurezza, test su larga scala e installazioni in ambienti di importanza rilevante. Questo canale è disponibile solo per i clienti e fornisce il pacchetto Nextcloud Enterprise."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
